spannertools.get_spanners_on_components_or_component_children
=============================================================

.. autofunction:: abjad.tools.spannertools.get_spanners_on_components_or_component_children.get_spanners_on_components_or_component_children
